@@ -1,7 +1,7 @@
 #include "SampG.h"
 
 void sampG(int nsamp, int **Gobs, int **G, int *nall, int nloci, int *id, double **A, int *categories, double **E_mat, int maxall, int maxrep, int *dam, int *sire, int nind, bool estA){
-
+         
         int l;                    // locus
         int i;                    // sample
         int o; 
@@ -21,7 +21,7 @@ void sampG(int nsamp, int **Gobs, int **G, int *nall, int nloci, int *id, double
         double vec[2][maxall];
         int which_vec = 0;
         int offhom_sizeS;
-        int cat_tmp[50];          // categories to which those genotypes belong
+        int cat_tmp[maxrep];      // categories to which those genotypes belong
         double Ppart[100];        // Probability vector for true genotypes
         int a1;                   // observed allele 1
         int a2;                   // observed allele 2
@@ -47,19 +47,19 @@ void sampG(int nsamp, int **Gobs, int **G, int *nall, int nloci, int *id, double
         int rel_status; 
         int samp_A;
         int no_base;
-        int par[nind][50];
+        int par[nind][100];
         int no_off[nind];
         int no_all_in_S;
         int IBL [2];             // variable for recording the number of alleles in offspring produced by selfing 
                                  // if there is only a single allele in the selfed offspring IBL[0] is the allele
                                  // and IBL[1] is the number of IBL[0] alleles in the selfed offspring.  If there 
                                  // are 2 alleles then IBL[1] is the second allele and the genotype of the indiviual is known.
-/*
+
         int oldG1;         // some variables that are used for bug checking
         int oldG2;
         bool problem;
         int j;
-*/
+
         for(o=0; o < nind; o++){
            no_off[o] = 0;
         }
@@ -76,7 +76,7 @@ void sampG(int nsamp, int **Gobs, int **G, int *nall, int nloci, int *id, double
               no_off[l]++;
            }
         }
-
+        
         IBL[0] = -999;
         IBL[1] = -999;
 
@@ -90,7 +90,6 @@ void sampG(int nsamp, int **Gobs, int **G, int *nall, int nloci, int *id, double
           }      
 
           for(i=0; i <nsamp; i++){                 // iterates through samples
-
                if(Gobs[i][l*2]!=-999){               
                  obs_G[n][0] = Gobs[i][l*2];       // gets observed genotypes 
                  obs_G[n][1] = Gobs[i][(l*2)+1];    
@@ -108,8 +107,8 @@ void sampG(int nsamp, int **Gobs, int **G, int *nall, int nloci, int *id, double
 
 if(id[i+q]!=ind){                 // the last record for that individual
 
-//               oldG1 = G[ind][l*2];          / some variables that are used for bug checking
-//               oldG2 = G[ind][(l*2)+1];
+               oldG1 = G[ind][l*2];          // some variables that are used for bug checking
+               oldG2 = G[ind][(l*2)+1];
 
 // get dam genotype //                
                 if(dam[ind]<nind){                 
@@ -551,6 +550,7 @@ case 2: // contextual information provided by both parents only /
             }else{
              G[ind][(l*2)+1] = sa[1];
             }
+
 break;     
 
 case 3:
@@ -1409,7 +1409,7 @@ case 4: // has offspring but no parents, or one parent //
 /* and also the old geneotypes before sampling on lines 109-110 */
 /****************************************************************/
 
-/*
+
        problem= FALSE;
 
        if(no_off[ind]>0){
@@ -1511,15 +1511,14 @@ case 4: // has offspring but no parents, or one parent //
            cout << "No Offspring exist" << endl;
          }
        }
-*/
+ 
           ind++;         
           n = 0; 
           misstype = 0;
         }                    // end this is the last record if statement
      }   
                     // end sample loop
-
-     if(estA==TRUE){
+      if(estA==TRUE){
         rdirichlet(newA, nl, PA);
         for(i=0; i < nl; i++){  
           A[l][i] = PA[i];
